@@ -82,6 +82,7 @@ class ErrorCodes(object):
     class ClientToken(object):
         CustomerDoesNotExist = "92804"
         FailOnDuplicatePaymentMethodRequiresCustomerId = "92803"
+        FailOnDuplicatePaymentMethodForCustomerRequiresCustomerId = "92805"
         InvalidDomainFormat = "92011"
         MakeDefaultRequiresCustomerId = "92801"
         MerchantAccountDoesNotExist = "92807"
@@ -105,6 +106,7 @@ class ErrorCodes(object):
         CvvIsRequired = "81706"
         CvvVerificationFailed = "81736"
         DuplicateCardExists = "81724"
+        DuplicateCardExistsForCustomer = "81763"
         ExpirationDateConflict = "91708"
         ExpirationDateIsInvalid = "81710"
         ExpirationDateIsRequired = "81709"
@@ -113,6 +115,8 @@ class ErrorCodes(object):
         ExpirationYearIsInvalid = "81713"
         InvalidParamsForCreditCardUpdate = "91745"
         InvalidVenmoSDKPaymentMethodCode = "91727" # NEXT_MJOR_VERSION remove this code
+        LimitExceededforDuplicatePaymentMethodCheckForCustomer = "81764"
+        NetworkTokenizationAttributeCryptogramIsRequired = "81762"
         NumberHasInvalidLength = NumberLengthIsInvalid = "81716"
         NumberIsInvalid = "81715"
         NumberIsProhibited = "81750"
@@ -408,6 +412,46 @@ class ErrorCodes(object):
         PaymentMethodNonceUnknown = "92908"
         TokenIsInUse = "92906"
 
+    class PayPalPaymentResource(object):
+        NonceExpired = "97301"
+        IdNotSupported = "97302"
+        NonceRequired = "97303"
+        InvalidEmail = "97304"
+        EmailTooLong = "97305"
+        ExpectedLineItemCollection = "97306"
+        ExpectedLineItemHash = "97307"
+        ExpectedLineItemDebit = "97308"
+        InvalidUnitAmount = "97309"
+        InvalidUnitTaxAmount = "97310"
+        IsoCodeRequired = "97311"
+        IsoCodeUnsupported = "97312"
+        ShippingFieldsMissing = "97313"
+        InvalidAmountBreakdown = "97314"
+        ExpectedShippingOptionCollection = "97315"
+        ShippingOptionsRequired = "97316"
+        ShippingOptionFieldsMissing = "97317"
+        InvalidShippingOptionType = "97318"
+        ShippingOptionIdReused = "97319"
+        TooManyShippingOptionsSelected = "97320"
+        ShippingOptionMustMatchBreakdown = "97321"
+        LineItemsShouldMatchTotal = "97322"
+        LineItemsTaxShouldMatchTotal = "97323"
+        PatchCallFailed = "97324"
+        InvalidAmount = "97325"
+        ShippingIdTooLong = "97326"
+        ShippingLabelTooLong = "97327"
+        ShippingFullNameTooLong = "97328"
+        ShippingAddressTooLong = "97329"
+        ShippingExtendedAddressTooLong = "97330"
+        ShippingLocalityTooLong = "97331"
+        ShippingRegionTooLong = "97332"
+        CountryCodeTooLong = "97333"
+        NationalNumberTooLong = "97334"
+        PostalCodeTooLong = "97335"
+        DescriptionTooLong = "97336"
+        CustomFieldTooLong = "97337"
+        OrderIdTooLong = "97338"
+
     class SettlementBatchSummary(object):
         CustomFieldIsInvalid = "82303"
         SettlementDateIsInvalid = "82302"
